@@ -66,12 +66,7 @@ define ([
         getLdapEmployeeObject = function () { return ldapEmployeeObject; },
 
         myProfile = function () {
-            var cu = currentUser('obj');
-            if (employeeProfile.effective !== null && employeeProfile.nick === cu.nick) {
-                target.pull('empProfile').start();
-            } else {
-                loadEmpProfile(currentUser('obj').eid);
-            }
+            loadEmpProfile(currentUser('obj').eid);
         },
 
         loadEmpProfile = function (eid) {
@@ -86,9 +81,8 @@ define ([
                         var priv = null,
                             effective = null;
                         if (st.payload.privhistory !== null) {
-                            priv = st.payload.privhistory.priv
-                            effective = st.payload.privhistory.effective
-                            effective = effective.substr(0, effective.indexOf(" "));
+                            priv = st.payload.privhistory.priv;
+                            effective = lib.readableDate(st.payload.privhistory.effective);
                         }
                         employeeProfile = $.extend(
                             Object.create(prototypes.empProfile), {
@@ -279,6 +273,10 @@ define ([
                         $.extend(obj, ldapEmployeeObject);
                         start.dbrowserListen();
                     }
+                    if (document.getElementById('empProfile')) {
+                        console.log("ldapSyncSelf AJAX success!");
+                        myProfile();
+                    }
                 },
                 // failure callback -- employee doesn't exist
                 fc = function (st) {
@@ -297,6 +295,10 @@ define ([
             ajax(rest, sc, fc);
         },
 
+        ldapSyncSelf = function (ldapEmp) {
+            return ldapSync(ldapEmp);
+        },
+
 	// epuGen ("generate employee profile update function") is called to
 	// save changes to the database
         //
@@ -342,6 +344,7 @@ define ([
         empProfileUpdate: function (emp) { epuGen('empProfile', emp); },
         ldapLookupSubmit: ldapLookupSubmit,
         ldapSync: ldapSync,
+        ldapSyncSelf: ldapSyncSelf,
         actionEmplSearch: actionEmplSearch,
         endTheMasquerade: endTheMasquerade,
         masqEmployee: masqEmp
